@@ -70,11 +70,11 @@ sub body {
             $elem->removeChild($_) for $elem->getChildNodes;
         }
         if (!_is_printable($data)) {
-            my $raw = Encode::encode("utf-8", $data);
+            Encode::_utf8_off($data);
             if (LIBXML) {
-               $elem->appendChild(XML::LibXML::Text->new(encode_base64($raw, '')));
+               $elem->appendChild(XML::LibXML::Text->new(encode_base64($data, '')));
             } else {
-               $elem->appendChild(XML::XPath::Node::Text->new(encode_base64($raw, '')));
+               $elem->appendChild(XML::XPath::Node::Text->new(encode_base64($data, '')));
             }
             $elem->setAttribute('mode', 'base64');
         } else {
@@ -130,7 +130,12 @@ sub body {
                 }
             } elsif ($mode eq 'base64') {
                 my $raw = decode_base64(LIBXML ? $elem->textContent : $elem->string_value);
-                $content->{__body} = Encode::decode("utf-8", $raw);
+                if ($content->type && $content->type =~ m!^text/!) {
+                    $content->{__body} = eval { Encode::decode("utf-8", $raw) } || $raw;
+                    Encode::_utf8_off($content->{__body}) unless $XML::Atom::ForceUnicode;
+                } else {
+                    $content->{__body} = $raw;
+                }
             } elsif ($mode eq 'escaped') {
                 $content->{__body} = LIBXML ? $elem->textContent : $elem->string_value;
             } else {
