@@ -123,16 +123,42 @@ sub entries_xpath {
 
 sub add_entry_libxml {
     my $feed = shift;
-    my($entry) = @_;
-    $feed->{doc}->getDocumentElement->appendChild($entry->{doc}->getDocumentElement);
+    my($entry, $opt) = @_;
+    $opt ||= {};
+    # When doing an insert, we try to insert before the first <entry> so
+    # that we don't screw up any preamble.  If there are no existing
+    # <entry>'s, then fall back to appending, which should be
+    # semantically identical.
+    my ($first_entry) =
+        $feed->{doc}->getDocumentElement->getChildrenByTagNameNS($entry->ns, 'entry');
+    if ($opt->{mode} && $opt->{mode} eq 'insert' && $first_entry) {
+        $feed->{doc}->getDocumentElement->insertBefore(
+            $entry->{doc}->getDocumentElement,
+            $first_entry,
+        );
+    } else {
+        $feed->{doc}->getDocumentElement->appendChild(
+            $entry->{doc}->getDocumentElement,
+        );
+    }
 }
 
 sub add_entry_xpath {
     my $feed = shift;
-    my($entry) = @_;
-    $feed->{doc}->appendChild($entry->{doc});
+    my($entry, $opt) = @_;
+    $opt ||= {};
+    my $set = $feed->{doc}->find("*[local-name()='entry' and namespace-uri()='" . $entry->ns . "']");
+    my $first_entry = $set ? ($set->get_nodelist)[0] : undef;
+    if ($opt->{mode} && $opt->{mode} eq 'insert' && $first_entry) {
+        $feed->{doc}->insertBefore($entry->{doc}, $first_entry);
+    } else {
+        $feed->{doc}->appendChild($entry->{doc});
+    }
 }
 
+__PACKAGE__->_rename_elements('modified' => 'updated');
+__PACKAGE__->_rename_elements('tagline' => 'subtitle');
+
 1;
 __END__
 
@@ -150,6 +176,8 @@ XML::Atom::Feed - Atom feed
     $entry->title('First Post');
     $entry->content('Post Body');
     $feed->add_entry($entry);
+    $feed->add_entry($entry, { mode => 'insert' });
+
     my @entries = $feed->entries;
     my $xml = $feed->as_xml;
 
@@ -229,6 +257,17 @@ the feed as a new I<E<lt>linkE<gt>> tag. For example:
     $link->href('http://www.example.com/');
     $feed->add_link($link);
 
+=head2 $feed->add_entry($entry)
+
+Adds the entry I<$entry>, which must be an I<XML::Atom::Entry> object,
+to the feed. If you want to add an entry before existent entries, you can pass optional hash reference containing C<mode> value set to C<insert>.
+
+  $feed->add_entry($entry, { mode => 'insert' });
+
+=head2 $feed->entries
+
+Returns list of XML::Atom::Entry objects contained in the feed.
+
 =head2 $feed->language
 
 Returns the language of the feed, from I<xml:lang>.
@@ -246,6 +285,28 @@ representing the author. For example:
     $author->email('foo@bar.com');
     $feed->author($author);
 
+=head1 UNICODE FLAGS
+
+By default, XML::Atom takes off all the Unicode flag fro mthe feed content. For example,
+
+  my $title = $feed->title;
+
+the variable C<$title> contains UTF-8 bytes without Unicode flag set,
+even if the feed title contains some multibyte chracters.
+
+If you don't like this behaviour and wants to andle everything as
+Unicode characters (rather than UTF-8 bytes), set
+C<$XML::Atom::ForceUnicode> flag to 1.
+
+  $XML::Atom::ForceUnicode = 1;
+
+then all the data returned from XML::Atom::Feed object and
+XML::Atom::Entry object etc., will have Unicode flag set.
+
+The only exception will be C<< $entry->content->body >>, if content
+type is not text/* (e.g. image/gif). In that case, the content body is
+still binary data, without Unicode flag set.
+
 =head1 AUTHOR & COPYRIGHT
 
 Please see the I<XML::Atom> manpage for author, copyright, and license
