@@ -73,6 +73,7 @@ sub version {
 sub init_xpath {
     my $atom = shift;
     my %param = @_ == 1 ? (Stream => $_[0]) : @_;
+    $atom->set_ns(\%param);
     my $elem_name = $atom->element_name;
     if (%param) {
         if (my $stream = $param{Stream}) {
@@ -118,7 +119,7 @@ sub get {
     my $val = LIBXML ? $node->textContent : $node->string_value;
     if ($] >= 5.008) {
         require Encode;
-        Encode::_utf8_off($val);
+        Encode::_utf8_off($val) unless $XML::Atom::ForceUnicode;
     }
     $val;
 }
@@ -132,7 +133,7 @@ sub getlist {
         my $val = LIBXML ? $_->textContent : $_->string_value;
         if ($] >= 5.008) {
             require Encode;
-            Encode::_utf8_off($val);
+            Encode::_utf8_off($val) unless $XML::Atom::ForceUnicode;
         }
         $val;
      } @node;
@@ -273,11 +274,11 @@ sub contributor {
 
 sub as_xml {
     my $doc = $_[0]->{doc};
-    remove_default_ns($doc->getDocumentElement);
+    remove_default_ns($doc->getDocumentElement) if LIBXML;
     my $xml = $doc->toString(LIBXML ? 1 : 0);
     if ($] > 5.008) {
         require Encode;
-        Encode::_utf8_off($xml);
+        Encode::_utf8_off($xml) unless $XML::Atom::ForceUnicode;
     }
     $xml;
 }
@@ -325,6 +326,27 @@ sub _element {
     wantarray ? @{$thing->{'__' . $name}} : $thing->{'__' . $name}->[0];
 }
 
+# 0.3 -> 1.0 elements aliasing
+sub _rename_elements {
+    my($class, $atom03, $atom10) = @_;
+    no strict 'refs';
+    *{"$class\::$atom03"} = sub {
+        my $self = shift;
+        if ($self->version eq "1.0") {
+            return $self->$atom10(@_);
+        }
+        @_ > 0 ? $self->set($self->ns, $atom03, @_) : $self->get($self->ns, $atom03);
+    };
+
+    *{"$class\::$atom10"} = sub {
+        my $self = shift;
+        if ($self->version eq "0.3") {
+            return $self->$atom03(@_);
+        }
+        @_ > 0 ? $self->set($self->ns, $atom10, @_) : $self->get($self->ns, $atom10);
+    };
+}
+
 sub DESTROY { }
 
 use vars qw( $AUTOLOAD );
