@@ -41,7 +41,7 @@ sub hack_unicode_entity {
     my $data = shift;
     Encode::_utf8_on($data);
     $data =~ s/&#x(\w{4});/chr(hex($1))/eg;
-    Encode::_utf8_off($data);
+    Encode::_utf8_off($data) unless $XML::Atom::ForceUnicode;
     $data;
 }
 
@@ -104,7 +104,7 @@ sub encode_xml {
 sub remove_default_ns {
     my($node) = @_;
     $node->setNamespace('http://www.w3.org/1999/xhtml', '')
-        if $node->nodeName =~ /^default:/ && ref($node) =~ /Element$/;
+        if ($node->nodeName) =~ /^default:/ && ref($node) =~ /Element$/;
     for my $n ($node->childNodes) {
         remove_default_ns($n);
     }
